==> ideaIC-2019.2.1-sources.jar: com/android/tools/idea/gradle/project/sync/idea/data/service/SyncIssueDataService.java <==
/*
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.project.sync.idea.data.service;

import com.android.tools.idea.gradle.project.sync.idea.data.model.SyncIssuesModel;
import com.android.tools.idea.gradle.project.sync.issues.SyncIssuesReporter;
import com.google.common.collect.Lists;
import com.intellij.openapi.externalSystem.model.DataNode;
import com.intellij.openapi.externalSystem.model.Key;
import com.intellij.openapi.externalSystem.model.project.ProjectData;
import com.intellij.openapi.externalSystem.service.project.IdeModifiableModelsProvider;
import com.intellij.openapi.externalSystem.service.project.manage.AbstractProjectDataService;
import com.intellij.openapi.project.Project;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Collection;

import static com.android.tools.idea.gradle.project.sync.idea.data.service.AndroidProjectKeys.SYNC_ISSUES;

public class SyncIssueDataService extends AbstractProjectDataService<SyncIssuesModel, Void> {
  @Override
  public void importData(@NotNull Collection<DataNode<SyncIssuesModel>> toImport,
                         @Nullable ProjectData projectData,
                         @NotNull Project project,
                         @NotNull IdeModifiableModelsProvider modelsProvider) {
    SyncIssuesReporter.getInstance().report(Lists.newArrayList(modelsProvider.getModules()));
  }

  @NotNull
  @Override
  public Key<SyncIssuesModel> getTargetDataKey() {
    return SYNC_ISSUES;
  }
}

==> ideaIC-2019.3.5-sources.jar: com/android/tools/idea/gradle/project/sync/idea/data/service/SyncIssueDataService.java <==
/*
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.project.sync.idea.data.service;

import static com.android.tools.idea.gradle.project.sync.idea.data.service.AndroidProjectKeys.SYNC_ISSUES;

import com.android.tools.idea.gradle.project.sync.idea.data.model.SyncIssuesModel;
import com.android.tools.idea.gradle.project.sync.issues.SyncIssuesReporter;
import com.intellij.openapi.externalSystem.model.DataNode;
import com.intellij.openapi.externalSystem.model.Key;
import com.intellij.openapi.externalSystem.model.project.ProjectData;
import com.intellij.openapi.externalSystem.service.project.IdeModifiableModelsProvider;
import com.intellij.openapi.externalSystem.service.project.manage.AbstractProjectDataService;
import com.intellij.openapi.project.Project;
import java.util.Collection;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class SyncIssueDataService extends AbstractProjectDataService<SyncIssuesModel, Void> {
  @Override
  public void importData(@NotNull Collection<DataNode<SyncIssuesModel>> toImport,
                         @Nullable ProjectData projectData,
                         @NotNull Project project,
                         @NotNull IdeModifiableModelsProvider modelsProvider) {
    SyncIssuesReporter.getInstance().report(project);
  }

  @NotNull
  @Override
  public Key<SyncIssuesModel> getTargetDataKey() {
    return SYNC_ISSUES;
  }
}
